package com.famoco.barcodescannerdemo;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.zebra.adc.decoder.BarCodeReader;


public class MainActivity extends Activity implements BarCodeReader.DecodeCallback {

    private TextView tvData = null;

    private BarCodeReader bcr = null;

    private String decodeDataString;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        tvData = (TextView)findViewById(R.id.tvData);
    }

    @Override
    protected void onPause() {
        super.onPause();
        if (bcr != null) {
            bcr.release();
            bcr = null;
        }
    }


    @Override
    protected void onResume() {
        super.onResume();

        try {
            if(android.os.Build.VERSION.SDK_INT >= 18)
                bcr = BarCodeReader.open(getApplicationContext()); // Android 4.3 and above
            else
                bcr = BarCodeReader.open(0); // Android 2.3

            if (bcr == null) {
                Toast.makeText(this, "open failed", Toast.LENGTH_LONG).show();
                return;
            }

            bcr.setDecodeCallback(this);

            // Set Orientation
            bcr.setParameter(687, 4); // 4 - omnidirectional

            // Sets OCR lines to decide
            //bcr.setParameter(691, 2); // 2 - OCR 2 lines
            bcr.setParameter(765, 0); //


        } catch (Exception e) {
            Toast.makeText(this, "open excp:" + e, Toast.LENGTH_LONG).show();
        }
    }


    public void onScan(View v) {

        decodeDataString = "";
        displayData(decodeDataString);

        try {
            bcr.startDecode(); // start decode (callback gets results)
        } catch (Exception e) {
            Toast.makeText(this, "open excp:" + e, Toast.LENGTH_LONG).show();
        }
    }

    // BarCodeReader.DecodeCallback override
    public void onDecodeComplete(int symbology, int length, byte[] data, BarCodeReader reader) {

        if (length > 0) {
            bcr.stopDecode();

            if (symbology == 0x99) {
                int n = data[1];
                int s = 2;
                int d = 0;
                int len = 0;
                byte d99[] = new byte[data.length];
                for (int i=0; i<n; ++i) {
                    s += 2;
                    len = data[s++];
                    System.arraycopy(data, s, d99, d, len);
                    s += len;
                    d += len;
                }
                d99[d] = 0;
                data = d99;
            }
            decodeDataString += new String(data);
            displayData(decodeDataString);

        } else {	// no-decode
            displayData("");
            switch (length) {
                case BarCodeReader.DECODE_STATUS_TIMEOUT:
                    Toast.makeText(this, "decode timed out", Toast.LENGTH_LONG).show();
                    break;
                case BarCodeReader.DECODE_STATUS_CANCELED:
                    Toast.makeText(this, "decode cancelled", Toast.LENGTH_LONG).show();
                    break;
                case BarCodeReader.DECODE_STATUS_ERROR:
                    Toast.makeText(this, "decode failed", Toast.LENGTH_LONG).show();
                    break;
                case BarCodeReader.DECODE_STATUS_MULTI_DEC_COUNT:
                    break;
                default:
                    break;
            }
        }

    }

    public void onEvent(int event, int info, byte[] data, BarCodeReader reader) {
        switch (event) {
            case BarCodeReader.BCRDR_EVENT_SCAN_MODE_CHANGED:
                Toast.makeText(this, "Scan Mode Changed Event", Toast.LENGTH_LONG).show();
                break;

            case BarCodeReader.BCRDR_EVENT_MOTION_DETECTED:
                Toast.makeText(this, "Motion Detect Event", Toast.LENGTH_LONG).show();
                break;

            case BarCodeReader.BCRDR_EVENT_SCANNER_RESET:
                Toast.makeText(this, "Reset Event", Toast.LENGTH_LONG).show();
                break;

            default:
                // process any other events here
                break;
        }
    }

    private void displayData(String data) {
        tvData.setText(data);
    }

}
